0.1.0a6 (2021-01-14)
--------------------

- fix issue with apikey model have renamed 'label' field to 'name'


0.1.0a5 (2020-12-24)
--------------------

- improve documentation
- reduce default database string column length
- compare types when generating updates
- fixed issue with deleting dictionary entity
- show user source in user listing
- validate reference data in display form
- added AGPL license notification page
- added AGPL exception agreement license enforcement hooks
- added type referencing/backreferencing UI
- added initial data visualization library
- use ESCapableRequest by default
- various UI fixes


0.1.0a4 (2020-11-23)
--------------------

- First release with changelog
